<script setup lang="ts">
import { logout } from "@/api/auth";
import ThemeSwitch from "@/components/ThemeSwitch.vue";
import ROUTE from "@/constants/route";
import useAuthUserStore from "@/stores/auth-user";
import useDashboardStore from "@/stores/dashboard";
import tokenStorage from "@/utils/tokenStorage";
import { Icon } from "@iconify/vue";
import { useMutation } from "@tanstack/vue-query";
import {
  ElAvatar,
  ElButton,
  ElIcon,
  ElMenu,
  ElMenuItem,
  ElPopover,
} from "element-plus";
import { storeToRefs } from "pinia";
import { useId } from "vue";
import { useI18n } from "vue-i18n";
import { useRouter } from "vue-router";

const { t } = useI18n();

const dashboardStore = useDashboardStore();
const { authUser } = storeToRefs(useAuthUserStore());
const router = useRouter();
const { isPending, mutate } = useMutation({
  mutationFn: logout,
  onSuccess: () => {
    tokenStorage.clear();
    router.push({ name: ROUTE.GUEST_LOGIN });
  },
});
</script>
<template>
  <header>
    <el-menu mode="horizontal" class="flex justify-between">
      <el-menu-item
        :index="useId()"
        @click="dashboardStore.expandSide = !dashboardStore.expandSide"
      >
        <el-icon>
          <template v-if="dashboardStore.expandSide">
            <Icon icon="ant-design:menu-fold-outlined" />
          </template>
          <template v-else>
            <Icon icon="ant-design:menu-unfold-outlined" />
          </template>
        </el-icon>
      </el-menu-item>

      <div class="flex items-center gap-3 mx-2">
        <el-popover>
          <template #reference>
            <el-menu-item :index="useId()">
              <el-avatar class="me-2">
                <Icon icon="mdi:user" />
              </el-avatar>
              <template #title>{{ authUser?.nickname }}</template>
            </el-menu-item>
          </template>
          <div class="flex flex-col gap-2">
            <el-button @click="mutate()" :loading="isPending" text>
              <template #icon>
                <Icon icon="material-symbols:logout" />
              </template>
              {{ t("common.logout") }}
            </el-button>
          </div>
        </el-popover>
        <theme-switch />
      </div>
    </el-menu>
  </header>
</template>
